@@ -92,16 +92,16 @@ fn update_member_deps(dir: &Path, version: &Version) -> HashMap<String, HashSet<
 }
 
 pub fn publish_workspace(dir: &Path, version: &Version) {
+
+    let graph = update_member_deps(dir, version);
+
     let mut cfg = Config::default().unwrap();
     cfg.set_values(cfg.load_values().unwrap()).unwrap();
     cfg.load_credentials().unwrap();
-
-    let graph = update_member_deps(dir, version);
-    let workspace_toml = dir.clone().join("Cargo.toml");
-    let workspace = Workspace::new(&workspace_toml, &cfg).unwrap();
+    let workspace = Workspace::new(&dir.clone().join("Cargo.toml"), &cfg).unwrap();
 
     let mut already_published: HashSet<String> = HashSet::new();
-
+    dbg!(&graph);
     for current_package in graph.keys() {
         publish_crate(
             &workspace,
